Package: worrms
Type: Package
Title: World Register of Marine Species (WoRMS) Client
Description: Client for World Register of Marine Species
    (<https://www.marinespecies.org/>). Includes functions for each
    of the API methods, including searching for names by name, date and
    common names, searching using external identifiers, fetching
    synonyms, as well as fetching taxonomic children and
    taxonomic classification.
Version: 0.4.3
Authors@R: c(
    person("Scott", "Chamberlain", role = "aut",
        email = "myrmecocystus@gmail.com",
        comment = c(ORCID = "0000-0003-1444-9135")),
    person("Bart", "Vanhoorne.", email = "bart.vanhoorne@vliz.be", role = c("aut","cre"))
    )
License: MIT + file LICENSE
URL: https://docs.ropensci.org/worrms/,
        https://github.com/ropensci/worrms (devel), https://taxize.dev
        (user manual)
BugReports: https://github.com/ropensci/worrms/issues
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
Imports: crul (>= 0.6.0), tibble (>= 1.2), jsonlite (>= 1.1),
        data.table
Suggests: roxygen2 (>= 7.1.0), knitr, rmarkdown, testthat, vcr (>=
        0.2.0)
RoxygenNote: 7.2.3
X-schema.org-applicationCategory: Biology
X-schema.org-keywords: biology, science, marine, API, web, api-client,
        worms, species
X-schema.org-isPartOf: https://ropensci.org
NeedsCompilation: no
Packaged: 2023-06-19 13:35:39 UTC; salvadorf
Author: Scott Chamberlain [aut] (<https://orcid.org/0000-0003-1444-9135>),
  Bart Vanhoorne. [aut, cre]
Maintainer: Bart Vanhoorne. <bart.vanhoorne@vliz.be>
Repository: CRAN
Date/Publication: 2023-06-20 14:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 16:53:15 UTC; unix
