# Generated by roxygen2: do not edit by hand

export(wm_attr_aphia)
export(wm_attr_aphia_)
export(wm_attr_category)
export(wm_attr_category_)
export(wm_attr_data)
export(wm_attr_data_)
export(wm_attr_def)
export(wm_attr_def_)
export(wm_children)
export(wm_children_)
export(wm_classification)
export(wm_classification_)
export(wm_common_id)
export(wm_common_id_)
export(wm_distribution)
export(wm_distribution_)
export(wm_external)
export(wm_external_)
export(wm_id2name)
export(wm_id2name_)
export(wm_name2id)
export(wm_name2id_)
export(wm_ranks_id)
export(wm_ranks_name)
export(wm_record)
export(wm_record_)
export(wm_record_by_external)
export(wm_record_by_external_)
export(wm_records_common)
export(wm_records_common_)
export(wm_records_date)
export(wm_records_name)
export(wm_records_names)
export(wm_records_rank)
export(wm_records_taxamatch)
export(wm_sources)
export(wm_sources_)
export(wm_synonyms)
export(wm_synonyms_)
